@@ -56,4 +56,5 @@ def run():
 			scm.push(args.protocol, args.username, reponame)
 		else:
 			print('Could not detect a git or hg repo in your current directory.')
-	
+	elif subcom == 'download':
+		download_file(subargs[0], subargs[1], subargs[2], args.password)
